# EP Framework

* [App](docs/App.md)

## Cache

Ovaj paket pruža [PSR-6](https://www.php-fig.org/psr/psr-6/) kompatibilne keševe, te koristi 
[Symfony Cache](https://symfony.com/doc/current/components/cache.html) za implementaciju.

Kako bi mogli koristiti Cache Item Poolove, potrebno ih je definirati u glavnoj konfiguraciji. Cache konfiguracije
se nalaze pod ključem `caches`. Konfiguracija bi izgledala ovako:

```php
<?php
return [
    // ...
    
    'caches' => [
        'moj-cache' => [
            'adapter' => 'redis',
            'options' => [
                'namespace' => 'moj',
                'connection' => 'redis://192.168.56.20',                            
            ],
        ],
    ],
    
    // ...
];
```

Keš je kasnije dostupan u glavnom containeru pod odabranim ključem:

```php
<?php
/** @var \Psr\Cache\CacheItemPoolInterface $cache */
$cache = $container->get('moj-cache');
```

Adapteri su dostupni u [PluginManageru](src/Cache/Adapter/PluginManager.php).

Također postoji i [AbstractCacheFactory](src/Cache/AbstractCacheFactory.php) koji se može dodati u container
kao `abstract_factory`, iako ga je bolje eksplicitno postaviti za dati keš.

## InputFilter

Proširili smo Factory klasu i omogućili zadavanje klase ValidatorChaina u specifikaciji Inputa. Dakle,
kada stvaramo InputFilter kroz konfiguraciju, možemo imati nešto poput...


```
'input_filter' => [
    'polje' => [
        'required' => true,
        'filters' => [
            ...
        ],
        'validator_chain' => MojValidatorChain::class,
        'validators' => [
            ...
        ],        
    ],
    ...
],
```

## Validator

Standardne stvari.

### [SmtpServer](src/Validator/SmtpServer.php)

Validira adresu SMTP servera.

### [DiseblableChain](src/Validator/Chain/DisableableChain.php)

DiseblableChain je ValidatorChain koji je moguće isključiti putem drugog polja iz konteksta, odnosno
uključuje se putem konteksta, npr...


```php
<?php
namespace Ep\Validator\Chain;

$chain = new DisableableChain([
    'name' => 'enabled',
    'value' => '1',
]);
$chain->attachByName('notempty');

// ne validiramo ništa, vraća true
$chain->isValid('', [
    'enabled' => '0',    
]);

// validiramo kroz chain, vraća false
$chain->isValid('', [
    'enabled' => '1',    
]);
```

### [EnableModuleChain](src/Validator/Chain/EnableModuleChain.php)

Ovo je u biti DisableableChain koji je iskonfiguriran kao ovaj u primjeru gore :).