import $ from 'jquery';
require('jquery-mousewheel');

import Element from './Element';

/**
 * <input type="number">
 */
export default class Number extends Element
{
    /**
     * Konstruktor.
     *
     * @param el
     */
    constructor(el)
    {
        super(el);

        if (!this.$el.is('input[type="number"]')) {
            throw 'el mora biti <input type="number">';
        }

        this.$el.on('change', this.onChange.bind(this));
        this.$el.on('focus', this.onFocus.bind(this));
        this.$el.on('mousewheel', this.onMouseWheel.bind(this));
    }

    /**
     * Najmanja vrijednost elementa.
     */
    get min()
    {
        return parseInt(this.$el.attr('min'));
    }

    /**
     * Najveća vrijednost elementa.
     */
    get max()
    {
        return parseInt(this.$el.attr('max'));
    }

    /**
     * Korak za koji umanjujemo/uvećavamo količinu.
     *
     * @returns {number}
     */
    get step()
    {
        return parseInt(this.$el.attr('step'));
    }

    /**
     * Da li je trenutna vrijednost ispravna
     *
     * @returns {boolean}
     */
    get valid()
    {
        return this.value >= this.min
            && (isNaN(this.max) || this.value <= this.max)
            && (this.value % this.step === 0);
    }

    /**
     * Trenutna vrijednost elementa.
     */
    get value()
    {
        return parseInt(this.$el.val());
    }

    /**
     * Trenutna vrijednost elementa.
     *
     * @param value
     */
    set value(value)
    {
        if (value === this.value) {
            return;
        }

        value = parseInt(value);

        value = Math.round(value / this.step) * this.step;

        if (value < this.min) {
            return;
        }

        if (!isNaN(this.max) && value > this.max) {
            return;
        }

        this.$el
            .val(value)
            .trigger('change');
    }

    /**
     * Umanjuje vrijednost za step.
     */
    decrement()
    {
        this.value = this.value - this.step;
    }

    /**
     * Uvećava vrijednost za step.
     */
    increment()
    {
        this.value = this.value + this.step;
    }

    /**
     * Kada se vrijednost elementa promijeni.
     */
    onChange()
    {
        $(this).trigger('change');
    }

    /**
     * Kada element dobije fokus.
     */
    onFocus()
    {
        this.$el.select();
    }

    /**
     * Kada korisnik okrene kotač nad elementom.
     *
     * @param e
     */
    onMouseWheel(e)
    {
        e.preventDefault();

        if (e.deltaY > 0) {
            this.increment();
        } else {
            this.decrement();
        }
    }
}