<?php
namespace Ep\Db\TableGateway;

use Interop\Container\ContainerInterface;
use Zend\Db\Sql\TableIdentifier;
use Zend\Db\TableGateway\TableGateway;
use Zend\Db\TableGateway\TableGatewayInterface;
use Zend\ServiceManager\Factory\AbstractFactoryInterface;

/**
 * Stvara nove instance TableGatewaya.
 *
 * @package Ep\Db\TableGateway
 * @author Elektronika Perhoč <web@ep.hr>
 * @link http://gitlab.ep.local/ep-framework/core
 */
class AbstractTableGatewayFactory implements AbstractFactoryInterface
{
    /**
     * Can the factory create an instance for the service?
     *
     * @param  ContainerInterface $container
     * @param  string $requestedName
     *
     * @return bool
     *
     * @throws \Psr\Container\ContainerExceptionInterface
     * @throws \Psr\Container\NotFoundExceptionInterface
     */
    public function canCreate(ContainerInterface $container, $requestedName)
    {
        $tables = $container->get('config')['db']['tables'] ?? [];
        return isset($tables[$requestedName]) && is_array($tables[$requestedName]);
    }

    /**
     * Create an object
     *
     * @param  ContainerInterface $container
     * @param  string $requestedName
     * @param  null|array $options
     *
     * @return TableGatewayInterface
     *
     * @throws \Psr\Container\ContainerExceptionInterface
     * @throws \Psr\Container\NotFoundExceptionInterface
     */
    public function __invoke(ContainerInterface $container, $requestedName, array $options = null)
    {
        $config = $container->get('config')['db']['tables'][$requestedName];

        if (!isset($config['name'])) {
            throw new \RuntimeException("Nedostaje parametar 'name'.");
        }

        $adapter = isset($config['adapter'])
            ? $container->get($config['adapter'])
            : $container->get('db');

        $gatewayClass = isset($config['gateway'])
            ? $config['gateway']
            : TableGateway::class;

        if (!class_exists($gatewayClass)) {
            throw new \RuntimeException(sprintf("Ne mogu pronaći TableGateway klasu '%s'.", $gatewayClass));
        }

        return new $gatewayClass(
            new TableIdentifier($config['name'], $config['schema'] ?? null),
            $adapter
        );
    }
}