<?php
namespace Ep\Form\View\Helper;

use Zend\Filter\Word\CamelCaseToDash;
use Ep\Form\Element\Button;
use Zend\Form\Element\Hidden;
use Zend\Form\ElementInterface;
use Zend\Form\View\Helper\AbstractHelper;

/**
 * Class FormGroup
 *
 * @package Ep\Form\View\Helper
 * @author Elektronika Perhoč <web@ep.hr>
 * @link http://gitlab.ep.local/ep-framework/core
 */
class FormGroup extends AbstractHelper
{
	/** @var FormLabel */
	protected $formLabel;

	/** @var FormControl */
	protected $formControl;

	/**
	 * Vraća FormLabel helper.
	 *
	 * @return FormLabel
	 */
	protected function getFormLabelHelper()
	{
		if (null === $this->formLabel) {
			$this->formLabel = method_exists($this->view, 'plugin')
				? $this->view->plugin('form_label')
				: new FormLabel();
		}

		return $this->formLabel;
	}

	/**
	 * Vraća FormControl helper.
	 *
	 * @return FormControl
	 */
	protected function getFormControlHelper()
	{
		if (null === $this->formControl) {
			$this->formControl = method_exists($this->view, 'plugin')
				? $this->view->plugin('form_control')
				: new FormControl();
		}

		return $this->formControl;
	}

    /**
     * @param ElementInterface|null $element
     *
     * @return FormGroup|string
     */
    public function __invoke(ElementInterface $element = null)
    {
        return $element ? $this->render($element) : $this;
    }

    /**
	 * Renderira grupu.
	 *
	 * @param ElementInterface $element    Element čiju grupu renderiramo.
	 *
	 * @return string
	 */
	public function render(ElementInterface $element)
	{
		$formLabel = $this->getFormLabelHelper();
		$formControl = $this->getFormControlHelper();

		$classes = ['form-group'];

		if ($group_class = $element->getOption('group_class')) {
		    $classes[] = is_array($group_class) ? implode(' ', $group_class) : $group_class;
        }

        $element_class = explode('\\', get_class($element));
        $filter = new CamelCaseToDash();

        $classes[] = sprintf('form-group-%s', strtolower($filter->filter(end($element_class))));

        // Label rendamo prije kontrole zato što FormLabel dodaje id elementu koji ga nema,
        // pa se to mora desiti prije nego što rendamo kontrolu.
		if ($element->getLabel()
		    && !$element instanceof Button
		    && !$element instanceof Hidden
		) {
			$label = $formLabel($element);
		} else {
			$label = '';
		}

		$control = $formControl->render($element);

		if ($element instanceof Hidden) {
			return $control;
		}

		$control = $label . "\n" . $control;

		return sprintf('<div class="%s">%s</div>', implode(' ', $classes), $control);
	}
}