<?php
namespace Ep\Validator;

use Zend\Validator\AbstractValidator;

/**
 * Provjerava da li string predstavlja minimalnu potrebnu verziju.
 *
 * @package Ep\Validator
 * @author Elektronika Perhoč <web@ep.hr>
 * @link http://gitlab.ep.local/ep-framework/core
 */
class MinVersion extends AbstractValidator
{
    const EMPTY_VERSION   = 'min_version.empty_version';
    const INVALID_VERSION = 'min_version.invalid_version';

    /** @var array */
    protected $messageTemplates = [
        self::EMPTY_VERSION   => 'Verzija je prazna.',
        self::INVALID_VERSION => 'Verzija %value% je manja od potrebne %min_version%.',
    ];

    /** @var array */
    protected $messageVariables = [
        'min_version' => ['options' => 'min_version'],
    ];

    /** @var array */
    protected $options = [
        'min_version' => '0.0.0',
    ];

    /**
     * Returns true if and only if $value meets the validation requirements
     *
     * If $value fails validation, then this method returns false, and
     * getMessages() will return an array of messages that explain why the
     * validation failed.
     *
     * @param  mixed $value
     *
     * @return bool
     */
    public function isValid($value)
    {
        $this->setValue($value);

        if (empty($value)) {
            $this->error(self::EMPTY_VERSION);
            return false;
        }

        if (-1 === version_compare($value, $this->options['min_version'])) {
            $this->error(self::INVALID_VERSION);
            return false;
        }

        return true;
    }
}