<?php
namespace EpTest\Cache;

use Ep\Cache\AbstractCacheFactory;
use EpTest\ContainerAwareTrait;
use PHPUnit\Framework\TestCase;
use Psr\Cache\CacheItemPoolInterface;

/**
 * Class AbstractCacheFactoryTest
 *
 * @package EpTest\Cache
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-framework
 */
class AbstractCacheFactoryTest extends TestCase
{
    use ContainerAwareTrait;

    /**
     * @throws \Psr\Container\ContainerExceptionInterface
     * @throws \Psr\Container\NotFoundExceptionInterface
     */
    public function testCanCreateAdapterFromConfig()
    {
        $container = $this->createContainer([
            'dependencies' => [
                'abstract_factories' => [
                    AbstractCacheFactory::class,
                ],
            ],

            'caches' => [
                'cache.apcu' => [
                    'adapter' => 'apcu',
                    'options' => [
                        'default_lifetime' => 12,
                    ],
                ],
            ],
        ]);

        $this->assertTrue($container->has('cache.apcu'));

        $cache = $container->get('cache.apcu');

        $this->assertInstanceOf(CacheItemPoolInterface::class, $cache);
        $this->assertSame($cache, $container->get('cache.apcu'));
    }

    /**
     * @expectedException \Zend\ServiceManager\Exception\ServiceNotCreatedException
     *
     * @throws \Psr\Container\ContainerExceptionInterface
     * @throws \Psr\Container\NotFoundExceptionInterface
     */
    public function testWillThrowExceptionWhenAdapterNotPresent()
    {
        $container = $this->createContainer([
            'dependencies' => [
                'abstract_factories' => [
                    AbstractCacheFactory::class,
                ],
            ],

            'caches' => [
                'cache.noadapter' => [
                    'options' => [],
                ],
            ],
        ]);

        $container->get('cache.noadapter');
    }

    /**
     * @expectedException \Zend\ServiceManager\Exception\ServiceNotCreatedException
     */
    public function testWillThrowExceptionIfConfigNotFound()
    {
        $container = $this->createContainer();
        $factory = new AbstractCacheFactory();

        $factory($container, 'config');
    }

    public function testCannotCreateCacheNamedConfig()
    {
        $container = $this->createContainer();
        $factory = new AbstractCacheFactory();

        $this->assertFalse($factory->canCreate($container, 'config'));
    }
    
    public function testWillNotBreakIfConfigEmpty()
    {
        $container = $this->createContainer();
        $factory = new AbstractCacheFactory();

        $this->assertFalse($factory->canCreate($container, 'some-cache'));
    }
}