<?php
namespace EpTest\Form\View\Helper;

use Ep\Form\View\Helper\FormLabel;
use EpTest\ContainerAwareTrait;
use PHPUnit\Framework\DOMTestCase;
use Zend\Form\Element\Text;
use Zend\ServiceManager\PluginManagerInterface;
use Zend\View\HelperPluginManager;

/**
 * Class FormLabelTest
 *
 * @package EpTest\Form\View\Helper
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-webshop
 */
class FormLabelTest extends DOMTestCase
{
    use ContainerAwareTrait;

    /**
     * @throws \Psr\Container\ContainerExceptionInterface
     * @throws \Psr\Container\NotFoundExceptionInterface
     */
    public function testHelperIsRegistered()
    {
        $container = $this->createContainer();
        /** @var PluginManagerInterface $helpers */
        $helpers = $container->get(HelperPluginManager::class);

        $this->assertTrue($helpers->has('form_label'));
        $this->assertInstanceOf(FormLabel::class, $helpers->get('form_label'));
    }

    public function testCanRenderLabel()
    {
        $element = new Text('test', [
            'label' => 'LABEL',
        ]);

        $element->setAttribute('id', 'test-element');

        $helper = new FormLabel();
        $rendered = $helper($element);

        $this->assertSelectCount('label', 1, $rendered, 'Nema <label> elementa.');
        $this->assertSelectCount('label[for="test-element"]', 1, $rendered, 'Nema `for` atributa.');
        $this->assertSelectCount('label.form-control-label', 1, $rendered, 'Nema bootstrap klase.');
        /** @noinspection PhpUnhandledExceptionInspection */
        $this->assertSelectEquals('label', 'LABEL', true, $rendered, 'Nema sadržaja.');
    }
}